@@ -16,14 +16,14 @@
 
 import sys
 from calculate.core.server.func import Action
-from calculate.install.distr import DistributiveError
-from calculate.install.migrate_users import MigrationError
+from ..distr import DistributiveError
+from ..migrate_users import MigrationError
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate, _
 from calculate.lib.cl_template import TemplatesError
 from calculate.lib.utils.files import FilesError
 from calculate.lib.utils.portage import isPkgInstalled
-from calculate.install.install import InstallError
-from calculate.install.variables.autopartition import AutopartitionError
+from ..install import InstallError
+from ..variables.autopartition import AutopartitionError
 
 setLocalTranslate('cl_install3', sys.modules[__name__])
 __ = getLazyLocalTranslate(_)
